#!/usr/bin/env python
# -*- coding: utf-8 -*-

# This file is part of sentimental.
# https://github.com/ErikGartner/sentimental

# Licensed under the - license:
# http://www.opensource.org/licenses/--license
# Copyright (c) 2016, Erik Gärtner <erik@gartner.io>

from sentimental.version import __version__  # NOQA
from sentimental.sentimental import Sentimental
from sentimental.example_extractor import ExampleExtractor
